@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -27,7 +27,11 @@ class KLineEdit;
 class QCheckBox;
 
 template <typename T> class QSharedPointer;
-
+namespace PimCommon
+{
+class IncidencesForWidget;
+class ContentTypeWidget;
+}
 namespace KIdentityManagement
 {
 class IdentityCombo;
@@ -37,14 +41,12 @@ namespace MailCommon
 {
 
 class FolderCollection;
-class IncidencesForWidget;
-class ContentTypeWidget;
 class MAILCOMMON_EXPORT CollectionGeneralPage : public Akonadi::CollectionPropertiesPage
 {
     Q_OBJECT
 
 public:
-    explicit CollectionGeneralPage(QWidget *parent = Q_NULLPTR);
+    explicit CollectionGeneralPage(QWidget *parent = nullptr);
     ~CollectionGeneralPage();
 
     void load(const Akonadi::Collection &collection) Q_DECL_OVERRIDE;
@@ -61,8 +63,8 @@ private Q_SLOTS:
 private:
     void addLine(QWidget *parent, QVBoxLayout *layout);
     QString mColorName;
-    ContentTypeWidget *mContentsComboBox;
-    IncidencesForWidget *mIncidencesForComboBox;
+    PimCommon::ContentTypeWidget *mContentsComboBox;
+    PimCommon::IncidencesForWidget *mIncidencesForComboBox;
     QCheckBox *mSharedSeenFlagsCheckBox;
     QCheckBox   *mNotifyOnNewMailCheckBox;
     QCheckBox   *mKeepRepliesInSameFolderCheckBox;
