@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -28,12 +28,12 @@ public:
     {
 
     }
-    FilterAction::ReturnCode process(MailCommon::ItemContext &, bool) const
+    FilterAction::ReturnCode process(MailCommon::ItemContext &, bool) const Q_DECL_OVERRIDE
     {
         return GoOn;
     }
 
-    MailCommon::SearchRule::RequiredPart requiredPart() const
+    MailCommon::SearchRule::RequiredPart requiredPart() const Q_DECL_OVERRIDE
     {
         return MailCommon::SearchRule::CompleteMessage;
     }
@@ -54,7 +54,7 @@ FilterActionWithAddressTest::~FilterActionWithAddressTest()
 void FilterActionWithAddressTest::shouldHaveDefaultValue()
 {
     TestFilterActionWithAddress filter;
-    QWidget *w = filter.createParamWidget(0);
+    QWidget *w = filter.createParamWidget(nullptr);
     QCOMPARE(w->objectName(), QStringLiteral("emailaddressrequester"));
     Akonadi::EmailAddressRequester *requester = dynamic_cast<Akonadi::EmailAddressRequester *>(w);
     QVERIFY(requester);
@@ -64,7 +64,7 @@ void FilterActionWithAddressTest::shouldHaveDefaultValue()
 void FilterActionWithAddressTest::shouldAssignValue()
 {
     TestFilterActionWithAddress filter;
-    QWidget *w = filter.createParamWidget(0);
+    QWidget *w = filter.createParamWidget(nullptr);
     Akonadi::EmailAddressRequester *requester = dynamic_cast<Akonadi::EmailAddressRequester *>(w);
     filter.argsFromString(QStringLiteral("foo"));
     filter.setParamWidgetValue(w);
