@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2011-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2011-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,14 +19,11 @@
 #ifndef MAILCOMMON_FILTERACTIONMISSINGARGUMENTDIALOG_H
 #define MAILCOMMON_FILTERACTIONMISSINGARGUMENTDIALOG_H
 
-#include "mailcommon_export.h"
-
+#include "mailcommon_private_export.h"
 #include <Collection>
 
 #include <QDialog>
 
-class KComboBox;
-class KUrlRequester;
 
 class QAbstractItemModel;
 class QListWidget;
@@ -37,27 +34,16 @@ class QPushButton;
 namespace MailCommon
 {
 class FolderRequester;
-class KMFilterAccountList;
 }
 
-namespace KIdentityManagement
-{
-class IdentityCombo;
-}
-
-namespace MailTransport
-{
-class TransportComboBox;
-}
-
-class MAILCOMMON_EXPORT FilterActionMissingCollectionDialog : public QDialog
+class MAILCOMMON_TESTS_EXPORT FilterActionMissingCollectionDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit FilterActionMissingCollectionDialog(const Akonadi::Collection::List &list,
             const QString &filtername = QString(),
             const QString &argStr = QString(),
-            QWidget *parent = Q_NULLPTR);
+            QWidget *parent = nullptr);
     ~FilterActionMissingCollectionDialog();
 
     Akonadi::Collection selectedCollection() const;
