@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -30,7 +30,7 @@ class FilterActionMissingSoundUrlDialog : public QDialog
 public:
     explicit FilterActionMissingSoundUrlDialog(const QString &filtername,
             const QString &argStr,
-            QWidget *parent = Q_NULLPTR);
+            QWidget *parent = nullptr);
     ~FilterActionMissingSoundUrlDialog();
     QString soundUrl() const;
 
