@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -56,7 +56,7 @@ class MailFilter;
 class QListWidgetFilterItem : public QListWidgetItem
 {
 public:
-    explicit QListWidgetFilterItem(const QString &text, QListWidget *parent = Q_NULLPTR);
+    explicit QListWidgetFilterItem(const QString &text, QListWidget *parent = nullptr);
     ~QListWidgetFilterItem();
 
     void setFilter(MailCommon::MailFilter *filter);
@@ -73,7 +73,7 @@ public:
     /**
      * Constructor.
      */
-    explicit KMFilterListBox(const QString &title, QWidget *widget = Q_NULLPTR);
+    explicit KMFilterListBox(const QString &title, QWidget *widget = nullptr);
 
     /**
      * Destructor.
