@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -36,17 +36,17 @@ class MailCommon::TagWidgetPrivate
 {
 public:
     TagWidgetPrivate()
-        : mTagNameLineEdit(Q_NULLPTR),
-          mTextColorCheck(Q_NULLPTR),
-          mBackgroundColorCheck(Q_NULLPTR),
-          mTextFontCheck(Q_NULLPTR),
-          mInToolbarCheck(Q_NULLPTR),
-          mTextColorCombo(Q_NULLPTR),
-          mBackgroundColorCombo(Q_NULLPTR),
-          mBoldCheckBox(Q_NULLPTR),
-          mItalicCheckBox(Q_NULLPTR),
-          mIconButton(Q_NULLPTR),
-          mKeySequenceWidget(Q_NULLPTR)
+        : mTagNameLineEdit(nullptr),
+          mTextColorCheck(nullptr),
+          mBackgroundColorCheck(nullptr),
+          mTextFontCheck(nullptr),
+          mInToolbarCheck(nullptr),
+          mTextColorCombo(nullptr),
+          mBackgroundColorCombo(nullptr),
+          mBoldCheckBox(nullptr),
+          mItalicCheckBox(nullptr),
+          mIconButton(nullptr),
+          mKeySequenceWidget(nullptr)
     {
 
     }
